# Auto generated, complete the functions below
{%for _import in imports_strings%}
{{_import}}{%endfor%}

class {{service_name}}_Servicer(object):{%for (_service, _in_var, _input_proto, _out_var, _output_proto) in service_tuples%}
  def {{_service}}({{_in_var}}: {{_input_proto}}) -> {{_output_proto}}:
    raise NotImplementedError
{%endfor%}
