syntax = "proto3";

import "google/protobuf/timestamp.proto";

service yqlCore {
  rpc Status(Echo) returns (Echo);
  rpc ProtoDefinitions(Echo) returns (Echo);
  rpc Predict(Echo) returns (Echo);
}

message Echo {
  google.protobuf.Timestamp server_time = 1;
  oneof data {
    string message = 2;
    string error = 3;
    string traceback = 4;
  };
  string rpc_name = 5;

  // proto_data is the jsonified message
  // on server side loads(proto_data) -> dict_to_message
  // on client side proto_data = message_to_json(client_message)
  // string proto_data = 6;

  // protobuf serilaised to the a base64 string
  string base64_string = 6; 
}
